==> nextalarm_0.2.8.tar.gz: nextalarm-0.2.8/src/nextalarm_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AlarmWindow</name>
    <message>
        <location filename="alarmwindow.ui" line="14"/>
        <source>AlarmWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="65"/>
        <source>alarms in next %1 h</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="162"/>
        <source>d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="220"/>
        <source>--:--</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="19"/>
        <source>Next Alarm settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="35"/>
        <source>Visual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="49"/>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="79"/>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="97"/>
        <source>I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="114"/>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="121"/>
        <source>12:48</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="140"/>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="166"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="193"/>
        <source>Transparency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="216"/>
        <source>Alarms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="227"/>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="244"/>
        <source>Alarms only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="249"/>
        <source>Alarms + Calendar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="254"/>
        <source>All Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="268"/>
        <source>recurrent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="275"/>
        <source>Frame (h)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="297"/>
        <source>Time Remain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="313"/>
        <source>Show widget Header</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="325"/>
        <source>Show alarm Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="337"/>
        <source>Show when empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="352"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="359"/>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="122"/>
        <source>Next Alarm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="123"/>
        <source>Developed with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="124"/>
        <source>Desktop widget, showing time of next alarms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="125"/>
        <source>Send reports to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="132"/>
        <source>About Next Alarm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> nextalarm_0.2.9.tar.gz: nextalarm-0.2.9/src/nextalarm_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AlarmWindow</name>
    <message>
        <location filename="alarmwindow.ui" line="14"/>
        <source>AlarmWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="69"/>
        <source>alarms in next %1 h</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="176"/>
        <source>d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="236"/>
        <source>--:--</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="19"/>
        <source>Next Alarm settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="35"/>
        <source>Visual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="49"/>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="86"/>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="104"/>
        <source>I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="133"/>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="140"/>
        <source>12:48</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="159"/>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="185"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="212"/>
        <source>Transparency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="235"/>
        <source>Alarms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="246"/>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="263"/>
        <source>Alarms only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="268"/>
        <source>Alarms + Calendar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="273"/>
        <source>All Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="281"/>
        <source>Frame (h)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="310"/>
        <source>recurrent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="329"/>
        <source>Show widget Header</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="341"/>
        <source>Show alarm Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="353"/>
        <source>Show when empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="371"/>
        <source>Show Time Remain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="386"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="393"/>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="124"/>
        <source>Next Alarm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="125"/>
        <source>Developed with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="126"/>
        <source>Desktop widget, showing time of next alarms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="127"/>
        <source>Send reports to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="134"/>
        <source>About Next Alarm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
